==> mypy_boto3_workspaces-0.2.7-py3-none-any.whl: mypy_boto3_workspaces/helpers.py <==
"Helper functions for workspaces service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_workspaces.client import Client
from mypy_boto3_workspaces.paginator import (
    DescribeAccountModificationsPaginator,
    DescribeIpGroupsPaginator,
    DescribeWorkspaceBundlesPaginator,
    DescribeWorkspaceDirectoriesPaginator,
    DescribeWorkspaceImagesPaginator,
    DescribeWorkspacesConnectionStatusPaginator,
    DescribeWorkspacesPaginator,
    ListAvailableManagementCidrRangesPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('workspaces')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("workspaces", **kwargs)
    return boto3.client("workspaces", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_account_modifications_paginator(
    client: Client,
) -> DescribeAccountModificationsPaginator:
    """
    Equivalent of `client.get_paginator('describe_account_modifications')`, returns a correct type.
    """
    return client.get_paginator("describe_account_modifications")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_ip_groups_paginator(client: Client) -> DescribeIpGroupsPaginator:
    """
    Equivalent of `client.get_paginator('describe_ip_groups')`, returns a correct type.
    """
    return client.get_paginator("describe_ip_groups")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_bundles_paginator(
    client: Client,
) -> DescribeWorkspaceBundlesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_bundles')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_bundles")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_directories_paginator(
    client: Client,
) -> DescribeWorkspaceDirectoriesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_directories')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_directories")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_images_paginator(
    client: Client,
) -> DescribeWorkspaceImagesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_images')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_images")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspaces_paginator(client: Client) -> DescribeWorkspacesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspaces')`, returns a correct type.
    """
    return client.get_paginator("describe_workspaces")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspaces_connection_status_paginator(
    client: Client,
) -> DescribeWorkspacesConnectionStatusPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspaces_connection_status')`, returns a correct type.
    """
    return client.get_paginator("describe_workspaces_connection_status")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_available_management_cidr_ranges_paginator(
    client: Client,
) -> ListAvailableManagementCidrRangesPaginator:
    """
    Equivalent of `client.get_paginator('list_available_management_cidr_ranges')`, returns a correct type.
    """
    return client.get_paginator("list_available_management_cidr_ranges")

==> mypy_boto3_workspaces-0.2.9-py3-none-any.whl: mypy_boto3_workspaces/helpers.py <==
"Helper functions for workspaces service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_workspaces.client import Client
from mypy_boto3_workspaces.paginator import (
    DescribeAccountModificationsPaginator,
    DescribeIpGroupsPaginator,
    DescribeWorkspaceBundlesPaginator,
    DescribeWorkspaceDirectoriesPaginator,
    DescribeWorkspaceImagesPaginator,
    DescribeWorkspacesConnectionStatusPaginator,
    DescribeWorkspacesPaginator,
    ListAvailableManagementCidrRangesPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('workspaces')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("workspaces", **kwargs)
    return boto3.client("workspaces", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_account_modifications_paginator(
    client: Client,
) -> DescribeAccountModificationsPaginator:
    """
    Equivalent of `client.get_paginator('describe_account_modifications')`, returns a correct type.
    """
    return client.get_paginator("describe_account_modifications")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_ip_groups_paginator(client: Client) -> DescribeIpGroupsPaginator:
    """
    Equivalent of `client.get_paginator('describe_ip_groups')`, returns a correct type.
    """
    return client.get_paginator("describe_ip_groups")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_bundles_paginator(client: Client) -> DescribeWorkspaceBundlesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_bundles')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_bundles")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_directories_paginator(
    client: Client,
) -> DescribeWorkspaceDirectoriesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_directories')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_directories")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspace_images_paginator(client: Client) -> DescribeWorkspaceImagesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspace_images')`, returns a correct type.
    """
    return client.get_paginator("describe_workspace_images")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspaces_paginator(client: Client) -> DescribeWorkspacesPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspaces')`, returns a correct type.
    """
    return client.get_paginator("describe_workspaces")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_workspaces_connection_status_paginator(
    client: Client,
) -> DescribeWorkspacesConnectionStatusPaginator:
    """
    Equivalent of `client.get_paginator('describe_workspaces_connection_status')`, returns a correct
    type.
    """
    return client.get_paginator("describe_workspaces_connection_status")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_list_available_management_cidr_ranges_paginator(
    client: Client,
) -> ListAvailableManagementCidrRangesPaginator:
    """
    Equivalent of `client.get_paginator('list_available_management_cidr_ranges')`, returns a correct
    type.
    """
    return client.get_paginator("list_available_management_cidr_ranges")
